# sw-python-utils
Soft Way company python utils

[![Build Status](https://travis-ci.org/telminov/sw-python-utils.svg?branch=master)](https://travis-ci.org/telminov/sw-python-utils)
[![Coverage Status](https://coveralls.io/repos/telminov/sw-python-utils/badge.svg?branch=master&service=github)](https://coveralls.io/github/telminov/sw-python-utils?branch=master)
